@@ -8,9 +8,11 @@ from typing import (
     Union,
     AnyStr,
     Mapping,
+    NewType,
     TypeVar,
     NoReturn,
     Optional,
+    FrozenSet,
     NamedTuple,
     DefaultDict,
     get_type_hints,
@@ -49,11 +51,13 @@ def test_types():
 
     assert types.Array.check_type(list)
     assert types.Array.check_type(tuple)
-    assert not types.Array.check_type(set)
+    assert types.Array.check_type(set)
     assert types.Array.check_type(List)
     assert types.Array.check_type(NamedTuple)
-    assert not types.Array.check_type(Set)
+    assert types.Array.check_type(Set)
     assert types.Array.check_type(Tuple)
+    assert types.Array.check_type(frozenset)
+    assert types.Array.check_type(FrozenSet)
     assert str(types.Array) == 'Array'
 
     assert types.Boolean.check_type(bool)
@@ -100,3 +104,43 @@ def test_types_from_fn():
     assert types.Array.check_type(fn_annotations['_d'])
     assert types.Object.check_type(fn_annotations['_e'])
     assert types.Boolean.check_type(fn_annotations['return'])
+
+
+# pylint: disable=E1136
+@pytest.mark.skipif(sys.version_info < (3, 9), reason='requires python3.9 or higher')
+def test_generic_type_alias():
+    T = TypeVar('T')
+
+    assert types.Array.check_type(list[int])
+    assert types.Array.check_type(list[float])
+    assert types.Array.check_type(set[str])
+    assert types.Array.check_type(frozenset[int])
+    assert types.Array.check_type(tuple[int])
+    assert types.Object.check_type(dict[int, str])
+    assert types.Object.check_type(dict[int, T][str])
+    assert types.Object.check_type(dict[int, list[int]])
+
+
+# pylint: disable=E1131
+@pytest.mark.skipif(sys.version_info < (3, 10), reason='requires python3.10 or higher')
+def test_union_type_expression():
+    assert types.Array.check_type(list[int | str])
+    assert types.String.check_type(str | bytearray)
+    assert types.String.check_type(bytearray | str)
+    assert types.String.check_type(str | None)
+    assert types.Number.check_type(int | float)
+
+
+@pytest.mark.skipif(sys.version_info < (3, 10), reason='requires python3.10 or higher')
+def test_none_type():
+    assert types.Null.check_type(type(None))
+    assert types.Null.check_type(types.NoneType)
+
+
+def test_new_type():
+    UserId = NewType('UserId', int)
+    UserUid = NewType('UserUid', str)
+
+    assert types.Number.check_type(UserId)
+    assert types.String.check_type(UserUid)
+    assert not types.Number.check_type(UserUid)
